Documentation
¶
Overview ¶
Package svipul is an advanced library and toolset for polling large amounts of network devices, initially with SNMP, but conceptually with any relevant protocol.
It works, or will work, through a central work-distribution database/api, and multiple, largely independent pollers. The results are reported using Skogul.
Index ¶
- Variables
- func Debug(v ...any)
- func Debugf(format string, v ...any)
- func Debugln(v ...any)
- func Fatal(v ...any)
- func Fatalf(format string, v ...any)
- func Fatalln(v ...any)
- func Init()
- func Log(v ...any)
- func Logf(format string, v ...any)
- func Logln(v ...any)
- func ParseConfig(f string) error
- type Node
- type Walker
Constants ¶
This section is empty.
Variables ¶
var Config conf = conf{ DefaultCommunity: "public", Workers: 10, Debug: false, MibPaths: []string{"mibs/modules"}, MaxMapAge: time.Second * 3600, Broker: "amqp://guest:guest@localhost:5672/", OutputConfig: "/etc/svipul/output.d/", MibModules: []string{ "ADSL-LINE-MIB", "ADSL-TC-MIB", "ALARM-MIB", "ATM-FORUM-MIB", "ATM-MIB", "ATM-TC-MIB", "BGP4-MIB", "BRIDGE-MIB", "DIFFSERV-DSCP-TC", "DIFFSERV-MIB", "DISMAN-PING-MIB", "DISMAN-TRACEROUTE-MIB", "DLSW-MIB", "DRAFT-MSDP-MIB", "DS1-MIB", "DS3-MIB", "ENTITY-MIB", "ENTITY-STATE-MIB", "ENTITY-STATE-TC-MIB", "ESO-CONSORTIUM-MIB", "EtherLike-MIB", "ETHER-WIS", "FRAME-RELAY-DTE-MIB", "FR-MFR-MIB", "GGSN-MIB", "GMPLS-LSR-STD-MIB", "GMPLS-TC-STD-MIB", "GMPLS-TE-STD-MIB", "HCNUM-TC", "HOST-RESOURCES-MIB", "HOST-RESOURCES-TYPES", "IANA-ADDRESS-FAMILY-NUMBERS-MIB", "IANA-GMPLS-TC-MIB", "IANAifType-MIB", "IANA-RTPROTO-MIB", "IEEE8021-CFM-MIB", "IEEE8021-CFM-V2-MIB", "IEEE8021-PAE-MIB", "IEEE8021-TC-MIB", "IEEE8023-LAG-MIB", "IF-MIB", "IGMP-STD-MIB", "INET-ADDRESS-MIB", "INTEGRATED-SERVICES-MIB", "IP-FORWARD-MIB", "IP-MIB", "IPMROUTE-MIB", "IPMROUTE-STD-MIB", "IPV6-FLOW-LABEL-MIB", "IPV6-MIB", "IPV6-TC", "ISIS-MIB", "LLDP-MIB", "MPLS-L3VPN-STD-MIB", "MPLS-LSR-STD-MIB", "MPLS-TC-STD-MIB", "MPLS-TE-STD-MIB", "MPLS-VPN-MIB", "OPT-IF-MIB", "OSPF-MIB", "OSPF-TRAP-MIB", "OSPFV3-MIB", "P-BRIDGE-MIB", "PerfHist-TC-MIB", "PIM-MIB", "POWER-ETHERNET-MIB", "PPP-LCP-MIB", "PTOPO-MIB", "Q-BRIDGE-MIB", "RADIUS-ACC-CLIENT-MIB", "RADIUS-AUTH-CLIENT-MIB", "RMON2-MIB", "RMON-MIB", "RSTP-MIB", "SNA-SDLC-MIB", "SNMP-COMMUNITY-MIB", "SNMP-FRAMEWORK-MIB", "SNMP-MPD-MIB", "SNMP-NOTIFICATION-MIB", "SNMP-PROXY-MIB", "SNMP-TARGET-MIB", "SNMP-USER-BASED-SM-MIB", "SNMPv2-MIB", "SNMPv2-SMI", "SNMPv2-TC", "SNMPv2-TM", "SNMP-VIEW-BASED-ACM-MIB", "SONET-MIB", "SYSAPPL-MIB", "TCP-MIB", "TOKEN-RING-RMON-MIB", "TRANSPORT-ADDRESS-MIB", "TUNNEL-MIB", "UDP-MIB", "VPN-TC-STD-MIB", "VRRP-MIB", "VRRPV3-MIB"}, }
Functions ¶
func ParseConfig ¶ added in v0.1.1
Types ¶
type Node ¶
type Node struct {
Key string // original input key, kept for posterity
Name string // sysName
Numeric string // .1.3.6.1.2.1.1.1 // root
Qualified string // .1.3.6.1.2.1.1.1.0 // "full", with index
Format string // 255a <-- possibly obsolete
Type *models.Type
Lookedup bool // True if key was not a pure OID
}
Node is a rendered SMI node, e.g.: the result of a lookup. Usually handled by the smierte sub-package, but needs to be defined up here to avoid circular dependencies
Directories
¶
| Path | Synopsis |
|---|---|
|
cmd
|
|
|
svipul-addjob
command
|
|
|
svipul-snmp
command
PS: While this started with a gosnmp walk-example, basically nothing is left of that, which is why I just removed the original copyright header, if you happen to be reading the git log.
|
PS: While this started with a gosnmp walk-example, basically nothing is left of that, which is why I just removed the original copyright header, if you happen to be reading the git log. |
|
Package inventory deals with inventory locking and syncing.
|
Package inventory deals with inventory locking and syncing. |
Click to show internal directories.
Click to hide internal directories.